CodeConfig class final

The configuration for CodeAssets in HookConfig.

Properties

android → AndroidCodeConfig
Configuration provided when CodeConfig.targetOS is OS.android.
no setter
cCompiler → CCompilerConfig?
A compiler toolchain able to target targetOS with targetArchitecture.
no setter
hashCode → int
The hash code for this object.
no setterinherited
iOS → IOSCodeConfig
Configuration provided when CodeConfig.targetOS is OS.macOS.
no setter
linkModePreference → LinkModePreference
no setter
macOS → MacOSCodeConfig
Configuration provided when CodeConfig.targetOS is OS.macOS.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetArchitecture → Architecture
The architecture the code code asset should be built for.
no setter
targetOS → OS
The operating system being compiled for.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited