DeveloperCommandPrompt class final

The configuration for the Windows Developer Command Prompt in WindowsCCompilerConfig.developerCommandPrompt.

Sets up the environment variables for CCompilerConfig.compiler, CCompilerConfig.linker, and CCompilerConfig.archiver on Windows.

Specific to CodeConfig.targetArchitecture.

Constructors

DeveloperCommandPrompt({required Uri script, required List<String> arguments})

Properties

arguments → List<String>
Arguments to invoke script with.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script → Uri
The path to the batch script that sets up the environment variables.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited