IOSSdk class final

The iOS SDK (device or simulator) in IOSCodeConfig.targetSdk.

Constructors

IOSSdk.fromString(String type)
The type of this IOSSdk.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
The type of this IOSSdk.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

iPhoneOS → const IOSSdk
The iphoneos SDK in Xcode.
iPhoneSimulator → const IOSSdk
The iphonesimulator SDK in Xcode.
values → const List<IOSSdk>
All known values for IOSSdk.