LinkMode class abstract final

The link mode for a CodeAsset.

Known linking modes:

See the documentation on the above classes.

Implementers

Constructors

LinkMode.fromJson(Map<String, Object?> json)
Constructs a LinkMode from the given json.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
The json representation of this LinkMode.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited