LinkModePreference class final

The preferred link mode for CodeAssets in CodeConfig.linkModePreference.

Constructors

LinkModePreference(String name)
const
LinkModePreference.fromString(String name)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name for this link mode.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

dynamic → const LinkModePreference
Provide native assets as dynamic libraries.
preferDynamic → const LinkModePreference
Provide native assets as dynamic libraries, if possible.
preferStatic → const LinkModePreference
Provide native assets as static libraries, if possible.
static → const LinkModePreference
Provide native assets as static libraries.
values → const List<LinkModePreference>