LookupInProcess class final

CodeAssets with this LinkMode are expected to have their symbols available through DynamicLibrary.process().

At buildtime, nothing happens.

Inheritance

Constructors

LookupInProcess()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
The json representation of this LinkMode.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited