StaticLinking class final

CodeAssets with this LinkMode are linked statically.

An asset with this link mode must provide a CodeAsset.file and it must be a static library.

At native linking time, native function names will be resolved to static libraries.

Not yet supported in the Dart and Flutter SDK.

Inheritance

Constructors

StaticLinking()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
The json representation of this LinkMode.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited